summaryrefslogtreecommitdiff
path: root/filter
diff options
context:
space:
mode:
authorAndrea Gelmini <andrea.gelmini@gelma.net>2015-10-02 13:04:33 +0200
committerAdolfo Jayme Barrientos <fitojb@ubuntu.com>2015-10-03 07:08:53 -0500
commitba65cb97bc806cad3bfa1a0cf443b41eff518059 (patch)
tree5b2cbcf1c92e2245156d91ced04fee0b389be5c3 /filter
parentc4d1a99ec667bdd661669afd72a708bd9a963db2 (diff)
Fix typos
Change-Id: Icde566ef79dc4ed8cb67a89c743f0a6c1b3c8f14
Diffstat (limited to 'filter')
-rw-r--r--filter/qa/complex/filter/detection/typeDetection/TypeDetection.java4
-rw-r--r--filter/qa/complex/filter/misc/FinalizedMandatoryTest.java2
-rw-r--r--filter/source/config/cache/basecontainer.cxx2
-rw-r--r--filter/source/config/cache/cacheitem.cxx20
-rw-r--r--filter/source/config/cache/cacheitem.hxx4
-rw-r--r--filter/source/config/cache/contenthandlerfactory.cxx2
-rw-r--r--filter/source/config/cache/filtercache.cxx10
-rw-r--r--filter/source/config/cache/filtercache.hxx8
-rw-r--r--filter/source/config/cache/filterfactory.cxx6
-rw-r--r--filter/source/config/cache/frameloaderfactory.cxx2
-rw-r--r--filter/source/config/cache/typedetection.cxx10
-rw-r--r--filter/source/config/cache/typedetection.hxx2
-rw-r--r--filter/source/flash/swfexporter.cxx2
-rw-r--r--filter/source/graphicfilter/eos2met/eos2met.cxx2
-rw-r--r--filter/source/graphicfilter/eps/eps.cxx2
15 files changed, 39 insertions, 39 deletions
diff --git a/filter/qa/complex/filter/detection/typeDetection/TypeDetection.java b/filter/qa/complex/filter/detection/typeDetection/TypeDetection.java
index 72fb1668d37a..5c87c22b8f6c 100644
--- a/filter/qa/complex/filter/detection/typeDetection/TypeDetection.java
+++ b/filter/qa/complex/filter/detection/typeDetection/TypeDetection.java
@@ -224,7 +224,7 @@ public class TypeDetection extends ComplexTestCase {
String kName = k.next();
log.println(kName + ":" + param.get(kName).toString());
}
- // create instrace of helper class
+ // create instance of helper class
helper = new Helper(param, log);
}
@@ -543,4 +543,4 @@ public class TypeDetection extends ComplexTestCase {
}
}
-} \ No newline at end of file
+}
diff --git a/filter/qa/complex/filter/misc/FinalizedMandatoryTest.java b/filter/qa/complex/filter/misc/FinalizedMandatoryTest.java
index 5967a7e0c3dd..1fed782eadf0 100644
--- a/filter/qa/complex/filter/misc/FinalizedMandatoryTest.java
+++ b/filter/qa/complex/filter/misc/FinalizedMandatoryTest.java
@@ -121,7 +121,7 @@ public class FinalizedMandatoryTest
/**
* test the given service <CODE>serviceName</CODE>.
- * For every filter a new instace was created and the tests started.
+ * For every filter a new instance was created and the tests started.
* @param serviceName the name of the service to test
*/
private void checkReadonlySupport(String serviceName) throws Exception
diff --git a/filter/source/config/cache/basecontainer.cxx b/filter/source/config/cache/basecontainer.cxx
index fa2a4682fb94..03f8c0f08ee8 100644
--- a/filter/source/config/cache/basecontainer.cxx
+++ b/filter/source/config/cache/basecontainer.cxx
@@ -92,7 +92,7 @@ void BaseContainer::impl_loadOnDemand()
// A generic container needs all items of a set of our cache!
// Of course it can block for a while, till the cache is really filled.
- // Note: dont load all sets supported by the cache here!
+ // Note: don't load all sets supported by the cache here!
FilterCache::EFillState eRequiredState = FilterCache::E_CONTAINS_NOTHING;
switch(m_eType)
diff --git a/filter/source/config/cache/cacheitem.cxx b/filter/source/config/cache/cacheitem.cxx
index 36420be2331c..ed235ca46b91 100644
--- a/filter/source/config/cache/cacheitem.cxx
+++ b/filter/source/config/cache/cacheitem.cxx
@@ -244,7 +244,7 @@ bool isSubSet(const css::uno::Any& aSubSet,
{
if (::std::find(stl_s2.begin(), stl_s2.end(), *it1) == stl_s2.end())
{
- _FILTER_CONFIG_LOG_1_("isSubSet() ... check for list types [OUString] ... dont found \"%s\" => return FALSE\n", _FILTER_CONFIG_TO_ASCII_(*it1))
+ _FILTER_CONFIG_LOG_1_("isSubSet() ... check for list types [OUString] ... didn't found \"%s\" => return FALSE\n", _FILTER_CONFIG_TO_ASCII_(*it1))
return false;
}
_FILTER_CONFIG_LOG_1_("isSubSet() ... check for list types [OUString] ... found \"%s\" => continue loop\n", _FILTER_CONFIG_TO_ASCII_(*it1))
@@ -271,7 +271,7 @@ bool isSubSet(const css::uno::Any& aSubSet,
::comphelper::SequenceAsHashMap::const_iterator it2 = stl_p2.find(it1->first);
if (it2 == stl_p2.end())
{
- _FILTER_CONFIG_LOG_1_("isSubSet() ... check for list types [PropertyValue] ... dont found \"%s\" => return FALSE\n", _FILTER_CONFIG_TO_ASCII_(it1->first))
+ _FILTER_CONFIG_LOG_1_("isSubSet() ... check for list types [PropertyValue] ... didn't found \"%s\" => return FALSE\n", _FILTER_CONFIG_TO_ASCII_(it1->first))
return false;
}
if (!isSubSet(it1->second, it2->second))
@@ -303,7 +303,7 @@ bool isSubSet(const css::uno::Any& aSubSet,
::comphelper::SequenceAsHashMap::const_iterator it2 = stl_n2.find(it1->first);
if (it2 == stl_n2.end())
{
- _FILTER_CONFIG_LOG_1_("isSubSet() ... check for list types [NamedValue] ... dont found \"%s\" => return FALSE\n", _FILTER_CONFIG_TO_ASCII_(it1->first))
+ _FILTER_CONFIG_LOG_1_("isSubSet() ... check for list types [NamedValue] ... didn't found \"%s\" => return FALSE\n", _FILTER_CONFIG_TO_ASCII_(it1->first))
return false;
}
if (!isSubSet(it1->second, it2->second))
@@ -337,7 +337,7 @@ bool CacheItem::haveProps(const CacheItem& lProps) const
const_iterator pItThis = this->find(pIt->first);
if (pItThis == this->end())
{
- _FILTER_CONFIG_LOG_1_("CacheItem::haveProps() ... dont found \"%s\" => return FALSE\n", _FILTER_CONFIG_TO_ASCII_(pIt->first))
+ _FILTER_CONFIG_LOG_1_("CacheItem::haveProps() ... didn't found \"%s\" => return FALSE\n", _FILTER_CONFIG_TO_ASCII_(pIt->first))
return false;
}
@@ -364,10 +364,10 @@ bool CacheItem::dontHaveProps(const CacheItem& lProps) const
pIt != lProps.end() ;
++pIt )
{
- // i) one item does not exists in general
+ // i) one item does not exist in general
// => continue with next one, because
- // "excluding" means ... "dont have it".
- // And "not exists" match to "dont have it".
+ // "excluding" means... "don't have it".
+ // And "not exists" matches to "don't have it".
const_iterator pItThis = this->find(pIt->first);
if (pItThis == this->end())
{
@@ -376,8 +376,8 @@ bool CacheItem::dontHaveProps(const CacheItem& lProps) const
}
// ii) one item have the right value => return false
- // because this item has the requested property ...
- // But we checked for "dont have it" here.
+ // because this item has the requested property...
+ // But we checked for "don't have it" here.
if (isSubSet(pIt->second, pItThis->second))
{
_FILTER_CONFIG_LOG_1_("CacheItem::dontHaveProps() ... item \"%s\" has same value => return FALSE!\n", _FILTER_CONFIG_TO_ASCII_(pIt->first))
@@ -387,7 +387,7 @@ bool CacheItem::dontHaveProps(const CacheItem& lProps) const
// this method was not breaked before =>
// That means: this item has no matching property
- // of the given set. It "dont have" it ... => return true.
+ // of the given set. It "don't have" it ... => return true.
_FILTER_CONFIG_LOG_("CacheItem::dontHaveProps() ... => return TRUE\n")
return true;
}
diff --git a/filter/source/config/cache/cacheitem.hxx b/filter/source/config/cache/cacheitem.hxx
index 56a5052c3879..6410be46c095 100644
--- a/filter/source/config/cache/cacheitem.hxx
+++ b/filter/source/config/cache/cacheitem.hxx
@@ -87,7 +87,7 @@ class CacheItem : public ::comphelper::SequenceAsHashMap
- /** @short check, if the given properties exists
+ /** @short check, if the given properties exist
at this item.
@descr All properties are compared in its minimum.
@@ -104,7 +104,7 @@ class CacheItem : public ::comphelper::SequenceAsHashMap
- /** @short check, if the given properties dont exists
+ /** @short check, if the given properties don't exist
at this item.
@descr All properties are compared in its minimum.
diff --git a/filter/source/config/cache/contenthandlerfactory.cxx b/filter/source/config/cache/contenthandlerfactory.cxx
index 23738f3a338c..6f808fee5898 100644
--- a/filter/source/config/cache/contenthandlerfactory.cxx
+++ b/filter/source/config/cache/contenthandlerfactory.cxx
@@ -99,7 +99,7 @@ css::uno::Reference< css::uno::XInterface > SAL_CALL ContentHandlerFactory::crea
}
// prevent outside code against NoSuchElementException!
- // But dont implement such defensive strategy for our new create handling :-)
+ // But don't implement such defensive strategy for our new create handling :-)
if (!m_rCache->hasItem(FilterCache::E_CONTENTHANDLER, sRealHandler))
return css::uno::Reference< css::uno::XInterface>();
}
diff --git a/filter/source/config/cache/filtercache.hxx b/filter/source/config/cache/filtercache.hxx
index 7570afb1bb16..e70e06a921e6 100644
--- a/filter/source/config/cache/filtercache.hxx
+++ b/filter/source/config/cache/filtercache.hxx
@@ -388,8 +388,8 @@ class FilterCache : public BaseLock
/** @short indicates if the requested sub container
contains some items.
- @descr We dont provide any information about the count
- of such items. Because we dont implement any index
+ @descr We don't provide any information about the count
+ of such items. Because we don't implement any index
based interface! The information "we have items or not"
must be enough for the outside code ... till somewhere
give us a good reason. :-)
@@ -449,7 +449,7 @@ class FilterCache : public BaseLock
see also EItemType.
@param sItem
- the key name of the requested item inside the pecified sub container.
+ the key name of the requested item inside the specified sub container.
@throw [css::uno::Exception]
if some input parameter are wrong or the cache itself is not valid
@@ -726,7 +726,7 @@ class FilterCache : public BaseLock
Wrong dependencies will be corrected automatically.
If something could not be repaired - an exception
is thrown.
- Further some optmized structures will be created.
+ Further some optimized structures will be created.
E.g.: a hash to map extensions to her types.
@attention There is no exception, if the cache could be repaired
diff --git a/filter/source/config/cache/frameloaderfactory.cxx b/filter/source/config/cache/frameloaderfactory.cxx
index 36a46c71c7a4..f6e84898511b 100644
--- a/filter/source/config/cache/frameloaderfactory.cxx
+++ b/filter/source/config/cache/frameloaderfactory.cxx
@@ -96,7 +96,7 @@ css::uno::Reference< css::uno::XInterface > SAL_CALL FrameLoaderFactory::createI
}
// prevent outside code against NoSuchElementException!
- // But dont implement such defensive strategy for our new create handling :-)
+ // But don't implement such defensive strategy for our new create handling :-)
if (!m_rCache->hasItem(FilterCache::E_FRAMELOADER, sRealLoader))
return css::uno::Reference< css::uno::XInterface>();
}
diff --git a/filter/source/config/cache/typedetection.cxx b/filter/source/config/cache/typedetection.cxx
index 16f204d95bab..4d8cc6d408a9 100644
--- a/filter/source/config/cache/typedetection.cxx
+++ b/filter/source/config/cache/typedetection.cxx
@@ -472,7 +472,7 @@ void TypeDetection::impl_checkResultsAndAddBestFilter(utl::MediaDescriptor& rDes
OUString& sType )
{
// a)
- // Dont overwrite a might preselected filter!
+ // Don't overwrite a might preselected filter!
OUString sFilter = rDescriptor.getUnpackedValueOrDefault(
utl::MediaDescriptor::PROP_FILTERNAME(),
OUString());
@@ -939,7 +939,7 @@ OUString TypeDetection::impl_detectTypeFlatAndDeep( utl::MediaDescriptor& r
continue;
}
- // dont forget to add every real asked deep detection service here.
+ // don't forget to add every real asked deep detection service here.
// Such detectors will be ignored if may be "impl_detectTypeDeepOnly()"
// must be called later!
rUsedDetectors.push_back(sDetectService);
@@ -1028,7 +1028,7 @@ OUString TypeDetection::impl_askDetectService(const OUString& sDet
try
{
// start deep detection
- // Dont forget to convert stl descriptor to its uno representation.
+ // Don't forget to convert stl descriptor to its uno representation.
/* Attention!
You have to use an explicit instance of this uno sequence ...
@@ -1086,9 +1086,9 @@ OUString TypeDetection::impl_askUserForTypeAndFilterIfAllowed(utl::MediaDescript
rDescriptor.getUnpackedValueOrDefault(utl::MediaDescriptor::PROP_INPUTSTREAM(),
css::uno::Reference< css::io::XInputStream >());
- // Dont distrub the user for "non existing files - means empty URLs" or
+ // Don't disturb the user for "non existing files - means empty URLs" or
// if we was forced to detect a stream.
- // Reason behind: We must be sure to ask user for "unknown contents" only ...
+ // Reason behind: we must be sure to ask user for "unknown contents" only...
// and not for "missing files". Especially if detection is done by a stream only
// we can't check if the stream points to an "existing content"!
if (
diff --git a/filter/source/config/cache/typedetection.hxx b/filter/source/config/cache/typedetection.hxx
index 14e179438193..08a17bc7c1c3 100644
--- a/filter/source/config/cache/typedetection.hxx
+++ b/filter/source/config/cache/typedetection.hxx
@@ -298,7 +298,7 @@ private:
Note: If the descriptor already include a filter
(may be selected by a FilterSelect interaction or preselected
- by the user itself) ... we dont change that here !
+ by the user itself) ... we don't change that here !
@param rDescriptor
reference to the MediaDescriptor (represented by an easy-to-use
diff --git a/filter/source/flash/swfexporter.cxx b/filter/source/flash/swfexporter.cxx
index 8ddc7fde7f4c..76ddbde5e6b6 100644
--- a/filter/source/flash/swfexporter.cxx
+++ b/filter/source/flash/swfexporter.cxx
@@ -193,7 +193,7 @@ bool FlashExporter::exportAll( Reference< XComponent > xDoc, Reference< XOutputS
for( nPage = 0; nPage < nPageCount; nPage++)
{
- // #i56084# keep PageNumber? We could determine the PageNumber of the single to-be-eported page
+ // #i56084# keep PageNumber? We could determine the PageNumber of the single to-be-exported page
// when exporting the selection, but this is only used for swf internal, so no need to do so (AFAIK)
mnPageNumber = nPage + 1;
diff --git a/filter/source/graphicfilter/eos2met/eos2met.cxx b/filter/source/graphicfilter/eos2met/eos2met.cxx
index 0fcbbdbbe2af..089935773080 100644
--- a/filter/source/graphicfilter/eos2met/eos2met.cxx
+++ b/filter/source/graphicfilter/eos2met/eos2met.cxx
@@ -132,7 +132,7 @@ private:
MapMode aPictureMapMode;
MapMode aTargetMapMode;
sal_uInt32 nActualFieldStartPos; // start position of the current 'Field'
- sal_uInt32 nNumberOfDataFields; // number of commenced 'Graphcis Data Fields'
+ sal_uInt32 nNumberOfDataFields; // number of commenced 'Graphics Data Fields'
Color aGDILineColor;
Color aGDIFillColor;
RasterOp eGDIRasterOp;
diff --git a/filter/source/graphicfilter/eps/eps.cxx b/filter/source/graphicfilter/eps/eps.cxx
index e62e31d22eb9..104a392ba4ce 100644
--- a/filter/source/graphicfilter/eps/eps.cxx
+++ b/filter/source/graphicfilter/eps/eps.cxx
@@ -2138,7 +2138,7 @@ void PSWriter::ImplText( const OUString& rUniString, const Point& rPos, const lo
{
if ( rUniString.isEmpty() )
return;
- if ( mnTextMode == 0 ) // using glpyh outlines
+ if ( mnTextMode == 0 ) // using glyph outlines
{
vcl::Font aNotRotatedFont( maFont );
aNotRotatedFont.SetOrientation( 0 );
diff --git a/filter/source/config/cache/filtercache.cxx b/filter/source/config/cache/filtercache.cxx
index d279481a804d..a26f5e0540ad 100644
--- a/filter/source/config/cache/filtercache.cxx
+++ b/filter/source/config/cache/filtercache.cxx
@@ -490,7 +490,7 @@ void FilterCache::addStatePropsToItem( EItemType eType,
::osl::ResettableMutexGuard aLock(m_aLock);
// Note: Opening of the configuration layer throws some exceptions
- // if it failed. So we dont must check any reference here ...
+ // if it failed. So we mustn't check any reference here...
css::uno::Reference< css::container::XNameAccess > xPackage;
css::uno::Reference< css::container::XNameAccess > xSet;
switch(eType)
@@ -563,11 +563,11 @@ void FilterCache::addStatePropsToItem( EItemType eType,
/* Ignore exceptions for missing elements inside configuration.
May by the following reason exists:
- The item does not exists inside the new configuration package org.openoffice.TypeDetection - but
- we got it from the old package org.openoffice.Office/TypeDetection. We dont migrate such items
+ we got it from the old package org.openoffice.Office/TypeDetection. We don't migrate such items
automatically to the new format. Because it will disturb e.g. the deinstallation of an external filter
package. Because such external filter can remove the old file - but not the automatically created new one ...
- => mark item as FINALIZED / MANDATORY, we dont support writing to the old format
+ => mark item as FINALIZED / MANDATORY, we don't support writing to the old format
*/
rItem[PROPNAME_FINALIZED] <<= sal_True;
rItem[PROPNAME_MANDATORY] <<= sal_True;
@@ -734,7 +734,7 @@ void FilterCache::detectFlatForURL(const css::util::URL& aURL ,
// ii) search types matching to the given extension.
- // Copy every macthing type without changing its order!
+ // Copy every matching type without changing its order!
// Because preferred types was added as first one during
// loading configuration.
CacheItemRegistration::const_iterator pExtReg = m_lExtensions2Types.find(sExtension);
@@ -1472,7 +1472,7 @@ void FilterCache::impl_loadSet(const css::uno::Reference< css::container::XNameA
// get names of all existing sub items of this set
// step over it and fill internal cache structures.
// But dont update optimized structures like e.g. hash
// for mapping extensions to its types!
const OUString* pItems = lItems.getConstArray();
@@ -1472,7 +1472,7 @@ void FilterCache::impl_loadSet(const css::uno::Reference< css::container::XNameA
// get names of all existing sub items of this set
// step over it and fill internal cache structures.
- // But dont update optimized structures like e.g. hash
+ // But don't update optimized structures like e.g. hash
// for mapping extensions to its types!
const OUString* pItems = lItems.getConstArray();
diff --git a/filter/source/config/cache/filterfactory.cxx b/filter/source/config/cache/filterfactory.cxx
index 9abfaa84d77b..51f34f8401f5 100644
--- a/filter/source/config/cache/filterfactory.cxx
+++ b/filter/source/config/cache/filterfactory.cxx
@@ -113,7 +113,7 @@ css::uno::Reference< css::uno::XInterface > SAL_CALL FilterFactory::createInstan
}
// prevent outside code against NoSuchElementException!
// But dont implement such defensive strategy for our new create handling :-)
if (!m_rCache->hasItem(FilterCache::E_FILTER, sRealFilter))
return css::uno::Reference< css::uno::XInterface>();
}
@@ -160,7 +160,7 @@ css::uno::Sequence< OUString > SAL_CALL FilterFactory::getAvailableServiceNames(
{
/* Attention: Instead of getElementNames() this method have to return only filter names,
which can be created as UNO Services really. Thats why we search for filters,
- which dont have a valid value for the property "FilterService".
+ which don't have a valid value for the property "FilterService".
Of course we can't check for corrupted service names here. We can check
for empty strings only ...
*/
@@ -547,7 +547,7 @@ OUStringList FilterFactory::impl_readSortedFilterListFromConfig(const OUString&
try
{
css::uno::Reference< css::container::XNameAccess > xUISortConfig = officecfg::TypeDetection::UISort::ModuleDependendFilterOrder::get(xContext);
// dont check the module name here. If it does not exists, an exception is thrown and catched below.
// We return an empty list as result then.
css::uno::Reference< css::container::XNameAccess > xModule;
xUISortConfig->getByName(sModule) >>= xModule;
@@ -113,7 +113,7 @@ css::uno::Reference< css::uno::XInterface > SAL_CALL FilterFactory::createInstan
}
// prevent outside code against NoSuchElementException!
- // But dont implement such defensive strategy for our new create handling :-)
+ // But don't implement such defensive strategy for our new create handling :-)
if (!m_rCache->hasItem(FilterCache::E_FILTER, sRealFilter))
return css::uno::Reference< css::uno::XInterface>();
@@ -547,7 +547,7 @@ OUStringList FilterFactory::impl_readSortedFilterListFromConfig(const OUString&
{
css::uno::Reference< css::container::XNameAccess > xUISortConfig = officecfg::TypeDetection::UISort::ModuleDependendFilterOrder::get(xContext);
- // dont check the module name here. If it does not exists, an exception is thrown and catched below.
+ // don't check the module name here. If it does not exists, an exception is thrown and catched below.
// We return an empty list as result then.
css::uno::Reference< css::container::XNameAccess > xModule;